/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ChessTask.cpp
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

/*------------------------------------------------------------- Includes */

#include <qapplication.h>
#include <qplatinumstyle.h>
#include <qtranslator.h>

#include "ctMainWindow.h"
#include "ctGlobal.h"

/*----------------------------------------------------- Global variables */

/** The language currently used by ChessTask */
int ctLanguage;

/*------------------------------------------------------------ Functions */

/** This is the main function that starts the application.
@param argc Number of arguments
@param argv Pointer to the array of arguments
@return 0 if the application was terminated by \a quit(), 
        the value given to \a exit() else
*/
int main(int argc, char **argv)
{
    QApplication a(argc, argv);
    QTranslator translator(0);

    ctLanguage = ENGLISH;
#ifdef DEFENGLISH    
    if (argc > 1)
    {
      if (argv[1] == QString("-german"))
      {
        ctLanguage = GERMAN;
        // Initialize translator for German
	translator.load("ct_de.qm", ".");
        a.installTranslator( &translator);
      }	
    }
#else
    if (argc > 1)
    {
      if (argv[1] != QString("-english"))
      {
        ctLanguage = GERMAN;
        // Initialize translator for German
	translator.load("ct_de.qm", ".");
        a.installTranslator( &translator);
      }	
    }
    else
    {
      ctLanguage = GERMAN;
      // Initialize translator for German
      translator.load("ct_de.qm", ".");
      a.installTranslator( &translator);
    }
#endif

    ctMainWindow *mw = new ctMainWindow();
    mw->setCaption( "ChessTask" );
    a.setMainWidget( mw );
    mw->resize(800, 600);

    mw->show();

    a.connect( &a, SIGNAL( lastWindowClosed() ), &a, SLOT( quit() ) );
    int result = a.exec();
    delete mw;
    return result;
}


