/* ChessTask - A graphical frontend for creating chess tasks in
*              LaTeX or HTML.
* Copyright (C) 2002-2004 by Dirk Baechle (dl9obn@darc.de)
*
* http://chesstask.sourceforge.net
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the 
*
* Free Software Foundation, Inc.
* 675 Mass Ave
* Cambridge
* MA 02139
* USA
*
*/

/** 
\file ctSignalRouter.cpp
\author Dirk Baechle
\date 2004-03-24
\version 2.0
*/

/*------------------------------------------------------------- Includes */

#include "ctSignalRouter.h"

/*------------------------------------------------------------ Functions */

/** Constructor for the \a ctSignalRouter class.
*/
ctSignalRouter::ctSignalRouter()
    : QObject()
{
   ; 
}

/*---------------------------------------------------------------- Slots */

/** Emits the \a sigOpenFile signal. 
*/
void ctSignalRouter::slotOpenFile()
{
  emit sigOpenFile();
}

/** Emits the \a sigAddFile signal. 
*/
void ctSignalRouter::slotAddFile()
{
  emit sigAddFile();
}

/** Emits the \a sigSaveFile signal. 
*/
void ctSignalRouter::slotSaveFile()
{
  emit sigSaveFile();
}

/** Emits the \a sigExportLatexFile signal. 
*/
void ctSignalRouter::slotExportLaTeXFile()
{
  emit sigExportLaTeXFile();
}

/** Emits the \a sigExportChessCards signal. 
*/
void ctSignalRouter::slotExportChessCardsFile()
{
  emit sigExportChessCardsFile();
}

/** Emits the \a sigExportHTML signal. 
*/
void ctSignalRouter::slotExportHTML()
{
  emit sigExportHTML();
}

/** Emits the \a sigExportLatexDirectory signal. 
*/
void ctSignalRouter::slotExportLaTeXDirectory()
{
  emit sigExportLaTeXDirectory();
}

/** Emits the \a sigExportChessCardsDirectory signal. 
*/
void ctSignalRouter::slotExportChessCardsDirectory()
{
  emit sigExportChessCardsDirectory();
}

/** Emits the \a sigExportHTMLDirectory signal. 
*/
void ctSignalRouter::slotExportHTMLDirectory()
{
  emit sigExportHTMLDirectory();
}

/** Emits the \a sigCopyLaTeXPosition signal. 
*/
void ctSignalRouter::slotCopyLaTeXPosition()
{
  emit sigCopyLaTeXPosition();
}

/** Emits the \a sigCopyLaTeXPosition signal. 
*/
void ctSignalRouter::slotCopyHTMLPosition()
{
  emit sigCopyHTMLPosition();
}

/** Emits the \a sigImportFENFile signal. 
*/
void ctSignalRouter::slotImportFENFile()
{
  emit sigImportFENFile();
}

/** Emits the \a sigImportEPDFile signal. 
*/
void ctSignalRouter::slotImportEPDFile()
{
  emit sigImportEPDFile();
}

/** Emits the \a sigDeleteAll signal. 
*/
void ctSignalRouter::slotDeleteAll()
{
  emit sigDeleteAll();
}

/** Emits the \a sigInsertTask signal. 
*/
void ctSignalRouter::slotInsertTask()
{
  emit sigInsertTask();
}

/** Emits the \a sigCopyTask signal. 
*/
void ctSignalRouter::slotCopyTask()
{
  emit sigCopyTask();
}

/** Emits the \a sigFirstTask signal. 
*/
void ctSignalRouter::slotFirstTask()
{
  emit sigFirstTask();
}

/** Emits the \a sigTaskBack signal. 
*/
void ctSignalRouter::slotTaskBack()
{
  emit sigTaskBack();
}

/** Emits the \a sigTaskForward signal. 
*/
void ctSignalRouter::slotTaskForward()
{
  emit sigTaskForward();
}

/** Emits the \a sigLastTask signal. 
*/
void ctSignalRouter::slotLastTask()
{
  emit sigLastTask();
}

/** Emits the \a sigDeleteTask signal. 
*/
void ctSignalRouter::slotDeleteTask()
{
  emit sigDeleteTask();
}

/** Emits the \a sigClearBoard signal. 
*/
void ctSignalRouter::slotClearBoard()
{
  emit sigClearBoard();
}

/** Emits the \a sigInitialPosition signal. 
*/
void ctSignalRouter::slotInitialPosition()
{
  emit sigInitialPosition();
}

/** Emits the \a sigSetMainTitle signal. 
*/
void ctSignalRouter::slotSetMainTitle()
{
  emit sigSetMainTitle();
}

/** Emits the \a sigRestoreTask signal. 
*/
void ctSignalRouter::slotRestoreTask()
{
  emit sigRestoreTask();
}

/** Emits the \a sigGenerateTitles signal. 
*/
void ctSignalRouter::slotGenerateTitles()
{
  emit sigGenerateTitles();
}

/** Emits the \a sigSetA4PaperSizeEnable signal. 
*/
void ctSignalRouter::slotSetA4PaperSizeEnable(bool enable)
{
  emit sigSetA4PaperSizeEnable(enable);
}

/** Emits the \a sigSetLaTeXDiagramSize signal. 
*/
void ctSignalRouter::slotSetLaTeXDiagramSize(int diagramSize)
{
  emit sigSetLaTeXDiagramSize(diagramSize);
}

/** Emits the \a sigSetTwoColumnsEnable signal. 
*/
void ctSignalRouter::slotSetTwoColumnsEnable(bool enable)
{
  emit sigSetTwoColumnsEnable(enable);
}

/** Emits the \a sigSetOneFileEnable signal. 
*/
void ctSignalRouter::slotSetOneFileEnable(bool enable)
{
  emit sigSetOneFileEnable(enable);
}

/** Emits the \a sigSetUseTTFontEnable signal. 
*/
void ctSignalRouter::slotSetUseTTFontEnable(bool enable)
{
  emit sigSetUseTTFontEnable(enable);
}

/** Emits the \a sigSetExpandSymbolsEnable signal. 
*/
void ctSignalRouter::slotSetExpandSymbolsEnable(bool enable)
{
  emit sigSetExpandSymbolsEnable(enable);
}

/** Emits the \a sigSetOutputSolutionsEnable signal. 
*/
void ctSignalRouter::slotSetOutputSolutionsEnable(bool enable)
{
  emit sigSetOutputSolutionsEnable(enable);
}

/** Emits the \a sigSetDirLevel signal. 
*/
void ctSignalRouter::slotSetDirLevel(int value)
{
  emit sigSetDirLevel(value);
}

/** Emits the \a sigSetFontSize signal. 
*/
void ctSignalRouter::slotSetFontSize(int value)
{
  emit sigSetFontSize(value);
}

